# ProjectInvitation

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [optional] [readonly] 
**email** | **str** | email of the user to invite | 
**redirect_uri** | **str** | User will be redirected to this uri when they accept the invitation | 
**role** | **int** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


